@@ -1,14 +1,13 @@
 # ABSTRACT: PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/) v1.0
 package PONAPI::Server;
 
-our $VERSION = '0.002001';
+our $VERSION = '0.002002';
 
 use Plack::Request;
 use Plack::Response;
 use HTTP::Headers::ActionPack;
 use Module::Runtime    ();
 use Return::MultiLevel ();
-use Path::Class::File  ();
 use JSON::XS           ();
 
 use PONAPI::Server::ConfigReader;
@@ -175,11 +174,11 @@ sub _ponapi_check_headers {
     # check Accept
     if ( my $accept = $req->headers->header('Accept') ) {
         my @jsonapi_accept =
-            map  { ( $_->[1]->subject eq $mt ) ? $_->[1] : () }
+            map { ( $_->[1]->type eq $mt ) ? $_->[1] : () }
             $pack->create_header( 'Accept' => $accept )->iterable;
 
         $wr->(ERR_WRONG_HEADER_ACCEPT)
-            if @jsonapi_accept and !( grep { !keys %{ $_->params } } @jsonapi_accept );
+            if @jsonapi_accept and !( grep { $_->params_are_empty } @jsonapi_accept );
     }
 }
 
@@ -287,7 +286,7 @@ PONAPI::Server - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/
 
 =head1 VERSION
 
-version 0.002001
+version 0.002002
 
 =head1 SYNOPSIS
 
